/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package sync4j.server.tools;

import sync4j.framework.protocol.IdGenerator;
import sync4j.framework.server.ID;
import sync4j.framework.server.store.*;

import sync4j.server.config.Configuration;

/**
 * This class works as a simple id generator that read his value from the datastore
 *
 * @version $Id: IdSpaceGenerator.java,v 1.1 2005/07/25 15:28:37 nichele Exp $
 */
public class IdSpaceGenerator
implements IdGenerator, java.io.Serializable {

    // -------------------------------------------------------------- Properties
    private ID id = null;

    // ------------------------------------------------------------ Constructors

    /**
     * Creates a new instance of IdSpaceGenerator
     *
     * @param idSpace the id space
     */
    public IdSpaceGenerator(String idSpace) {
        id = new ID(idSpace);
    }


    /**
     * Reset the generator to 0.
     */
    public void reset() {
        id.setValue(0);
        try {
            Configuration.getConfiguration().getStore().store(id);
        } catch (PersistentStoreException ex) {
            throw new IllegalStateException("Error resetting the counter '" + id.getIdSpace() + "': " + ex.getMessage());
        }
    }

    /**
     * Returns the next value of the counter
     *
     * @return the next generated value
     */
    public synchronized String next() {
        try {
            Configuration.getConfiguration().getStore().read(id);
        } catch (PersistentStoreException ex) {
            throw new IllegalStateException("Error reading the counter '" + id.getIdSpace() + "': " + ex.getMessage());
        }
        return String.valueOf(id.getValue());
    }

    /**
     * Returns the last generated id (which is the current id).
     *
     * @return the last generated id
     */
    public synchronized String current() {
        return String.valueOf(id.getValue());
    }
}
