--
-- This script contains the ddl to create the engine database.
--
-- @version $id: create_engine.ddl,v 1.23 2005/06/13 17:25:44 nichele exp $
--

create table sync4j_principal
(
  username    varchar(32)  not null,
  device      varchar(128) not null,
  id          integer      not null,
  primary key (id)
);

create table sync4j_user
(
  username   varchar(32) not null,
  password   varchar(32) not null,
  email      varchar(50),
  first_name varchar(255),
  last_name  varchar(255),
  primary key (username)
);

create table sync4j_device
(
  id              varchar(128) not null,
  description     varchar(255),
  type            varchar(255),
  client_nonce    varchar(255),
  server_nonce    varchar(255),
  server_password varchar(255),
  id_caps         integer default '2' not null,
  timezone        varchar(50),  
  convert_date    char(1), 
  charset         varchar(50),    
  primary key (id)
);

create table sync4j_device_caps
(
  id              integer not null,
  largeobject     char(1) default 'N' not null,
  numberofchanges char(1) default 'N' not null,
  primary key (id)
);

create table sync4j_sync_source
(
  uri        varchar(128) not null,
  config     varchar(255) not null,
  name       varchar(200) not null,
  sourcetype varchar(128) not null,
  primary key (uri)
);

create table sync4j_last_sync
(
  principal          integer      not null,
  sync_source        varchar(128) not null,
  last_anchor_server varchar(20),
  last_anchor_client varchar(20),
  start_sync         date,
  end_sync           date,
  primary key (principal, sync_source)
);

create table sync4j_client_mapping
(
  principal   integer      not null,
  sync_source varchar(128) not null,
  luid        varchar(200) not null,
  guid        varchar(200) not null,
  primary key (principal, sync_source, luid, guid)
);


create table sync4j_id
(
  idspace varchar(30) not null,
  counter integer     not null,
  primary key (idspace)
);

create table sync4j_module
(
  id          varchar(128) not null,
  name        varchar(200) not null,
  description varchar(200),
  primary key (id)
);

create table sync4j_sync_source_type
(
  id           varchar(128) not null,
  description  varchar(200),
  class        varchar(255) not null,
  admin_class  varchar(255),
  primary key (id)
);

create table sync4j_module_sync_source_type
(
  module     varchar(128) not null,
  sourcetype varchar(128) not null,
  primary key (module, sourcetype)
);

create table sync4j_connector
(
  id            varchar(128) not null,
  name          varchar(200) not null,
  description   varchar(200),
  admin_class   varchar(255),
  primary key (id)
);

create table sync4j_module_connector
(
  module      varchar(128) not null,
  connector   varchar(128) not null,
  primary key (module, connector)
);

create table sync4j_connector_source_type
(
  connector  varchar(128) not null,
  sourcetype varchar(128) not null,
  primary key (connector, sourcetype)
);

create table sync4j_role
(
  role        varchar(128) not null,
  description varchar(200) not null,
  primary key (role)
);

create table sync4j_user_role
(
  username varchar(32 ) not null,
  role     varchar(128) not null,
  primary key (username,role)
);


alter table sync4j_principal add constraint fk_user foreign key (
  username
)
references sync4j_user (
  username
) on delete cascade;


alter table sync4j_principal add constraint fk_device foreign key (
  device
)
references sync4j_device (
  id
) on delete cascade;


alter table sync4j_last_sync add constraint fk_principal foreign key (
  principal
)
references sync4j_principal (
  id
) on delete cascade;


alter table sync4j_last_sync add constraint fk_source foreign key (
  sync_source
)
references sync4j_sync_source (
  uri
) on delete cascade;


alter table sync4j_client_mapping add constraint fk_principal1 foreign key (
  principal
)
references sync4j_principal (
  id
) on delete cascade;


alter table sync4j_client_mapping add constraint fk_source1 foreign key (
  sync_source
)
references sync4j_sync_source (
  uri
) on delete cascade;

alter table sync4j_device add constraint fk_device_caps foreign key (
  id_caps
)
references sync4j_device_caps (
  id
) on delete cascade;

create index ind_principal on sync4j_principal (username, device);
create index ind_user      on sync4j_user      (username, password);